@@ -7,7 +7,7 @@
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
- * as published by the Free Software Foundation; either version 2    
+ * as published by the Free Software Foundation; either version 3    
  * of the License, or any later version.                             
  *                                                                   
  *                                                                   
@@ -18,13 +18,11 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
 
-#include <X11/extensions/XTest.h>
-
 #include "libxnee/xnee.h"
 #include "libxnee/print.h"
 #include "libxnee/xnee_record.h"
@@ -32,9 +30,8 @@
 #include "libxnee/xnee_sem.h"
 #include "libxnee/xnee_resolution.h"
 
-
-int
-xnee_replay_buffer_status (xnee_data* xd, int data_type, int nr);
+#ifndef XNEE_XNEE_BUFFER_H
+#define XNEE_XNEE_BUFFER_H
 
 int
 xnee_replay_buffer_max_diff (xnee_data* xd, int type);
@@ -76,3 +73,6 @@ xnee_replay_buffer_status (xnee_data* xd, int data_type, int nr);
 int 
 xnee_update_buffer_cache(xnee_data *xd);
 
+
+
+#endif /* XNEE_XNEE_BUFFER_H */
