@@ -3,9 +3,7 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
- *                      2004, 2005, 2006, 2007, 2008
- *                      2009, 2010, 2011, 2013  Henrik Sandklef                    
+ *   Copyright (C) 1999-2011, 2013, 2014  Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -890,5 +888,10 @@ xnee_get_max_nr_of_moves(xnee_data *xd);
 int 
 xnee_set_max_nr_of_moves(xnee_data *xd, int moves);
 
+int 
+xnee_set_override_display(xnee_data *xd, int mode);
+
+int 
+xnee_get_override_display(xnee_data *xd);
 
 #endif /* XNEE_SETGET_H */ 
