@@ -3,7 +3,7 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 2010, 2011 Henrik Sandklef                    
+ *        Copyright (C) 2010, 2011, 2013 Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -50,6 +50,11 @@
 #define xnee_xinput_request_keyboard(xd)  \
   xd->xi_data.xinput_record_keyboard=1;
 
+#define xnee_xinput_unrequest_mouse(xd)     \
+  xd->xi_data.xinput_record_mouse=0;
+#define xnee_xinput_unrequest_keyboard(xd)  \
+  xd->xi_data.xinput_record_keyboard=0;
+
 #define xnee_xinput_mouse_requested(xd)   \
   (xd->xi_data.xinput_record_mouse==1)
 #define xnee_xinput_keyboard_requested(xd)\
