@@ -33,6 +33,7 @@
 #include "libxnee/print_varargs.h"
 #include "libxnee/xnee_resolution.h"
 #include "libxnee/xnee_display.h"
+#include "libxnee/xnee_xinput.h"
 
 /**************************************************************
  *                                                            *
@@ -233,7 +234,6 @@ xnee_add_display_list ( xnee_data* xd, char * disp)
 {
   char buf[256];
   size_t next;
-  size_t len;
   int ret=0;
   int disp_len;
 
@@ -254,7 +254,6 @@ xnee_add_display_list ( xnee_data* xd, char * disp)
     if (next==0) break; 
     strncpy(buf,disp,next);
     buf[next]='\0';
-    len =strlen(disp);
     disp+=next+1;
     disp_len=disp_len - next - 1;
     ret=xnee_add_display_str (buf,xd);
@@ -295,29 +294,27 @@ xnee_add_display_str (char * disp_str, xnee_data* xd)
   int xtest_error_basep = 0;
   int xtest_version_major = 0;
   int xtest_version_minor = 0;
-  
+  xnee_distr *xdist;
+
   xnee_verbose((xd, "Adding Display \"%s\" to distribution list\n", disp_str));
   
+  xdist = xd->distr_list;
   if (xd->distr_list_size==0) 
     {
-      xnee_verbose((xd, 
-		    "Adding Display - allocating memory for the first time\n"
-		    ));
-      xd->distr_list = (xnee_distr *) calloc (1,sizeof (xnee_distr));
+      xdist = NULL;
     }
-  else 
+
+  xnee_distr *tmp = xd->distr_list;
+  xd->distr_list = (xnee_distr *) realloc (xd->distr_list, 
+					   (xd->distr_list_size+1)*sizeof (xnee_distr));
+
+  if (xd->distr_list==NULL)
     {
-      xnee_distr *tmp = xd->distr_list;
-      xd->distr_list = (xnee_distr *) realloc (xd->distr_list, 
-					       xd->distr_list_size);
-      if (xd->distr_list==NULL)
-	{
-	  /*@ignore@*/
-	  xd->distr_list = tmp;
-	  /*@end@*/
-	  tmp = NULL;
-	  return XNEE_MEMORY_FAULT;
-	}
+      /*@ignore@*/
+      xd->distr_list = tmp;
+      /*@end@*/
+      tmp = NULL;
+      return XNEE_MEMORY_FAULT;
     }
   
   
